# Changelog

## 1.2.0 (2025-06-13)

Full Changelog: [v1.1.0...v1.2.0](https://github.com/coingecko/coingecko-python/compare/v1.1.0...v1.2.0)

### Features

* **api:** manual updates ([7ff4d0d](https://github.com/coingecko/coingecko-python/commit/7ff4d0d6989cc21fcc41f383b0483d45484d14e7))

## 1.1.0 (2025-06-13)

Full Changelog: [v1.0.1...v1.1.0](https://github.com/coingecko/coingecko-python/compare/v1.0.1...v1.1.0)

### Features

* **api:** Update example response ([ea77eac](https://github.com/coingecko/coingecko-python/commit/ea77eacb32e83b5adf9935eae92dc9bbe29e5a69))


### Bug Fixes

* **client:** correctly parse binary response | stream ([7df7dc4](https://github.com/coingecko/coingecko-python/commit/7df7dc4a59b037a167ed63c849c08436aac08bde))


### Chores

* **tests:** run tests in parallel ([115a0dc](https://github.com/coingecko/coingecko-python/commit/115a0dcd97d26d7005a72a47c24c49bc4b0713b3))

## 1.0.1 (2025-06-10)

Full Changelog: [v1.0.0...v1.0.1](https://github.com/coingecko/coingecko-python/compare/v1.0.0...v1.0.1)

### Chores

* **internal:** version bump ([8773836](https://github.com/coingecko/coingecko-python/commit/87738364b7ecbf1c534528067548d5ad75282809))

## 1.0.0 (2025-06-10)

Full Changelog: [v0.1.0-alpha.7...v1.0.0](https://github.com/coingecko/coingecko-python/compare/v0.1.0-alpha.7...v1.0.0)

### Chores

* update SDK settings ([4fd9a80](https://github.com/coingecko/coingecko-python/commit/4fd9a80c750f4de6facf297537ae9bb1b267ceca))

## 0.1.0-alpha.7 (2025-06-08)

Full Changelog: [v0.1.0-alpha.6...v0.1.0-alpha.7](https://github.com/coingecko/coingecko-python/compare/v0.1.0-alpha.6...v0.1.0-alpha.7)

### Features

* **api:** Update to coingecko_sdk ([262a767](https://github.com/coingecko/coingecko-python/commit/262a76703b119bcc2648db0e21a63d9400a8719c))

## 0.1.0-alpha.6 (2025-06-07)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/coingecko/coingecko-python/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Features

* **api:** api update ([9f7378c](https://github.com/coingecko/coingecko-python/commit/9f7378c9775aa51e345033dded23a26e65878b97))
* **api:** New endpoints ([fd3b486](https://github.com/coingecko/coingecko-python/commit/fd3b486f6528d71be7df3a5a9186ace2742819bd))

## 0.1.0-alpha.5 (2025-06-03)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/coingecko/coingecko-python/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **client:** add follow_redirects request option ([f01e996](https://github.com/coingecko/coingecko-python/commit/f01e99674f5b0e7d243395588ad6a87e88eda894))


### Chores

* **docs:** remove reference to rye shell ([5c72fbf](https://github.com/coingecko/coingecko-python/commit/5c72fbf675d06b2b8ccfd36604d01cc28ad9a637))

## 0.1.0-alpha.4 (2025-06-02)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/coingecko/coingecko-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** update via SDK Studio ([0c72a75](https://github.com/coingecko/coingecko-python/commit/0c72a7510464ed2bc0620d1ed64b6ab40f7145b7))

## 0.1.0-alpha.3 (2025-05-29)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/coingecko/coingecko-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** update via SDK Studio ([0812f21](https://github.com/coingecko/coingecko-python/commit/0812f2163205be4e48486f201ab979b78593e9a1))

## 0.1.0-alpha.2 (2025-05-28)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/coingecko/coingecko-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([3869350](https://github.com/coingecko/coingecko-python/commit/3869350a197c6e83fe5c68199ea6047bc177cf14))

## 0.1.0-alpha.1 (2025-05-28)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/coingecko/coingecko-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([2b17650](https://github.com/coingecko/coingecko-python/commit/2b17650480b4d839844a1fb09a7a1eba74a48966))
* **api:** update via SDK Studio ([c7b2f6c](https://github.com/coingecko/coingecko-python/commit/c7b2f6c7a949b1ac299601712e291dd22cad5d20))
* **api:** update via SDK Studio ([2e88eda](https://github.com/coingecko/coingecko-python/commit/2e88edae53fe8c78f114d83a069bdcd90e1505ef))


### Chores

* update SDK settings ([616d906](https://github.com/coingecko/coingecko-python/commit/616d9066a6514fb0f9d33dd941a135bcf84700ca))
